[edk2-devel] [PATCH 05/79] EmulatorPkg/Sec: Fix various typos

Philippe Mathieu-Daudé via Groups.Io philmd=redhat.com at groups.io
Tue Dec 3 16:14:48 UTC 2019


From: Antoine Coeur <coeur at gmx.fr>

Fix various typos in comments and documentation.

Cc: Jordan Justen <jordan.l.justen at intel.com>
Cc: Andrew Fish <afish at apple.com>
Cc: Ray Ni <ray.ni at intel.com>
Signed-off-by: Coeur <coeur at gmx.fr>
Reviewed-by: Philippe Mathieu-Daude <philmd at redhat.com>
Signed-off-by: Philippe Mathieu-Daude <philmd at redhat.com>
---
 EmulatorPkg/Sec/Sec.h              |  4 ++--
 EmulatorPkg/Sec/Sec.c              |  5 ++---
 EmulatorPkg/Sec/Ia32/SwitchRam.S   | 18 +++++++++---------
 EmulatorPkg/Sec/Ia32/SwitchRam.asm | 20 ++++++++++----------
 EmulatorPkg/Sec/X64/SwitchRam.S    |  2 +-
 EmulatorPkg/Sec/X64/SwitchRam.asm  |  2 +-
 6 files changed, 25 insertions(+), 26 deletions(-)

diff --git a/EmulatorPkg/Sec/Sec.h b/EmulatorPkg/Sec/Sec.h
index dd301f788868..42554e05b56e 100644
--- a/EmulatorPkg/Sec/Sec.h
+++ b/EmulatorPkg/Sec/Sec.h
@@ -1,5 +1,5 @@
 /*++ @file
-  Stub SEC that is called from the OS appliation that is the root of the emulator.
+  Stub SEC that is called from the OS application that is the root of the emulator.
 
   The OS application will call the SEC with the PEI Entry Point API.
 
@@ -23,7 +23,7 @@ SPDX-License-Identifier: BSD-2-Clause-Patent
 
 
 //
-// I think this shold be defined in a MdePkg include file?
+// I think this should be defined in a MdePkg include file?
 //
 VOID
 EFIAPI
diff --git a/EmulatorPkg/Sec/Sec.c b/EmulatorPkg/Sec/Sec.c
index b734d2bb8799..1c0f73d66944 100644
--- a/EmulatorPkg/Sec/Sec.c
+++ b/EmulatorPkg/Sec/Sec.c
@@ -1,5 +1,5 @@
 /*++ @file
-  Stub SEC that is called from the OS appliation that is the root of the emulator.
+  Stub SEC that is called from the OS application that is the root of the emulator.
 
   The OS application will call the SEC with the PEI Entry Point API.
 
@@ -90,7 +90,7 @@ _ModuleEntryPoint (
     SecReseveredMemorySize += sizeof (EFI_PEI_PPI_DESCRIPTOR);
 
     if ((Ppi->Flags & EFI_PEI_PPI_DESCRIPTOR_TERMINATE_LIST) == EFI_PEI_PPI_DESCRIPTOR_TERMINATE_LIST) {
-      // Since we are appending, need to clear out privious list terminator.
+      // Since we are appending, need to clear out previous list terminator.
       Ppi->Flags &= ~EFI_PEI_PPI_DESCRIPTOR_TERMINATE_LIST;
       break;
     }
@@ -138,4 +138,3 @@ _ModuleEntryPoint (
 }
 
 
-
diff --git a/EmulatorPkg/Sec/Ia32/SwitchRam.S b/EmulatorPkg/Sec/Ia32/SwitchRam.S
index f24529cc8e61..d8298223a9b0 100644
--- a/EmulatorPkg/Sec/Ia32/SwitchRam.S
+++ b/EmulatorPkg/Sec/Ia32/SwitchRam.S
@@ -9,7 +9,7 @@
 #
 # Abstract:
 #
-#   Switch the stack from temporary memory to permenent memory.
+#   Switch the stack from temporary memory to permanent memory.
 #
 #------------------------------------------------------------------------------
 
@@ -36,7 +36,7 @@ ASM_PFX(SecSwitchStack):
 
 #
 # !!CAUTION!! this function address's is pushed into stack after
-# migration of whole temporary memory, so need save it to permenent
+# migration of whole temporary memory, so need save it to permanent
 # memory at first!
 #
 
@@ -44,14 +44,14 @@ ASM_PFX(SecSwitchStack):
     movl  24(%esp), %ecx            # Save the second parameter
 
 #
-# Save this function's return address into permenent memory at first.
-# Then, Fixup the esp point to permenent memory
+# Save this function's return address into permanent memory at first.
+# Then, Fixup the esp point to permanent memory
 #
 
     movl  %esp, %eax
     subl  %ebx, %eax
     addl  %ecx, %eax
-    movl  (%esp), %edx                 # copy pushed register's value to permenent memory
+    movl  (%esp), %edx                 # copy pushed register's value to permanent memory
     movl  %edx, (%eax)
     movl  4(%esp), %edx
     movl  %edx, 4(%eax)
@@ -61,16 +61,16 @@ ASM_PFX(SecSwitchStack):
     movl  %edx, 12(%eax)
     movl  16(%esp), %edx
     movl  %edx, 16(%eax)
-    movl  %eax, %esp                   # From now, esp is pointed to permenent memory
+    movl  %eax, %esp                   # From now, esp is pointed to permanent memory
 
 #
-# Fixup the ebp point to permenent memory
+# Fixup the ebp point to permanent memory
 #
 #ifndef __APPLE__
     movl   %ebp, %eax
     subl   %ebx, %eax
     addl   %ecx, %eax
-    movl   %eax, %ebp                  # From now, ebp is pointed to permenent memory
+    movl   %eax, %ebp                  # From now, ebp is pointed to permanent memory
 
 #
 # Fixup callee's ebp point for PeiDispatch
@@ -78,7 +78,7 @@ ASM_PFX(SecSwitchStack):
     movl   (%ebp), %eax
     subl   %ebx, %eax
     addl   %ecx, %eax
-    movl   %eax, (%ebp)                # From now, Temporary's PPI caller's stack is in permenent memory
+    movl   %eax, (%ebp)                # From now, Temporary's PPI caller's stack is in permanent memory
 #endif
 
     pop   %edx
diff --git a/EmulatorPkg/Sec/X64/SwitchRam.S b/EmulatorPkg/Sec/X64/SwitchRam.S
index 7ddb6c854b00..59d4e2edef2a 100644
--- a/EmulatorPkg/Sec/X64/SwitchRam.S
+++ b/EmulatorPkg/Sec/X64/SwitchRam.S
@@ -1,7 +1,7 @@
 #------------------------------------------------------------------------------
 #
 # Copyright (c) 2006 - 2011, Intel Corporation. All rights reserved.<BR>
-# Portitions copyright (c) 2011, Apple Inc. All rights reserved.
+# Portions copyright (c) 2011, Apple Inc. All rights reserved.
 # SPDX-License-Identifier: BSD-2-Clause-Patent
 #
 #------------------------------------------------------------------------------
diff --git a/EmulatorPkg/Sec/X64/SwitchRam.asm b/EmulatorPkg/Sec/X64/SwitchRam.asm
index 73530bff39c2..e66bda5bf4e6 100644
--- a/EmulatorPkg/Sec/X64/SwitchRam.asm
+++ b/EmulatorPkg/Sec/X64/SwitchRam.asm
@@ -1,7 +1,7 @@
 ;------------------------------------------------------------------------------
 ;
 ; Copyright (c) 2006 - 2012, Intel Corporation. All rights reserved.<BR>
-; Portitions copyright (c) 2011, Apple Inc. All rights reserved.
+; Portions copyright (c) 2011, Apple Inc. All rights reserved.
 ; SPDX-License-Identifier: BSD-2-Clause-Patent
 ;
 ;------------------------------------------------------------------------------
diff --git a/EmulatorPkg/Sec/Ia32/SwitchRam.asm b/EmulatorPkg/Sec/Ia32/SwitchRam.asm
index 9c7908f7a04c..99ef00298069 100644
--- a/EmulatorPkg/Sec/Ia32/SwitchRam.asm
+++ b/EmulatorPkg/Sec/Ia32/SwitchRam.asm
@@ -9,7 +9,7 @@
 ;
 ; Abstract:
 ;
 ;   Switch the stack from temporary memory to permenent memory.
 ;
 ;------------------------------------------------------------------------------
 
@@ -36,7 +36,7 @@ SecSwitchStack   PROC
 
     ;
     ; !!CAUTION!! this function address's is pushed into stack after
     ; migration of whole temporary memory, so need save it to permenent
     ; memory at first!
     ;
 
@@ -44,13 +44,13 @@ SecSwitchStack   PROC
     mov   ecx, [esp + 24]          ; Save the second parameter
 
     ;
     ; Save this function's return address into permenent memory at first.
     ; Then, Fixup the esp point to permenent memory
     ;
     mov   eax, esp
     sub   eax, ebx
     add   eax, ecx
-    mov   edx, dword ptr [esp]         ; copy pushed register's value to permenent memory
+    mov   edx, dword ptr [esp]         ; copy pushed register's value to permanent memory
     mov   dword ptr [eax], edx
     mov   edx, dword ptr [esp + 4]
     mov   dword ptr [eax + 4], edx
@@ -58,17 +58,17 @@ SecSwitchStack   PROC
     mov   dword ptr [eax + 8], edx
     mov   edx, dword ptr [esp + 12]
     mov   dword ptr [eax + 12], edx
-    mov   edx, dword ptr [esp + 16]    ; Update this function's return address into permenent memory
+    mov   edx, dword ptr [esp + 16]    ; Update this function's return address into permanent memory
     mov   dword ptr [eax + 16], edx
-    mov   esp, eax                     ; From now, esp is pointed to permenent memory
+    mov   esp, eax                     ; From now, esp is pointed to permanent memory
 
     ;
     ; Fixup the ebp point to permenent memory
     ;
     mov   eax, ebp
     sub   eax, ebx
     add   eax, ecx
-    mov   ebp, eax                ; From now, ebp is pointed to permenent memory
+    mov   ebp, eax                ; From now, ebp is pointed to permanent memory
 
     ;
     ; Fixup callee's ebp point for PeiDispatch
@@ -76,7 +76,7 @@ SecSwitchStack   PROC
     mov   eax, dword ptr [ebp]
     sub   eax, ebx
     add   eax, ecx
-    mov   dword ptr [ebp], eax    ; From now, Temporary's PPI caller's stack is in permenent memory
+    mov   dword ptr [ebp], eax    ; From now, Temporary's PPI caller's stack is in permanent memory
 
     pop   edx
     pop   ecx
@@ -9,7 +9,7 @@
 ; Abstract:
 ;
-;   Switch the stack from temporary memory to permenent memory.
+;   Switch the stack from temporary memory to permanent memory.
 ;
 ;------------------------------------------------------------------------------
@@ -36,7 +36,7 @@ SecSwitchStack   PROC
     ;
     ; !!CAUTION!! this function address's is pushed into stack after
-    ; migration of whole temporary memory, so need save it to permenent
+    ; migration of whole temporary memory, so need save it to permanent
     ; memory at first!
     ;
@@ -44,13 +44,13 @@ SecSwitchStack   PROC
 
     ;
-    ; Save this function's return address into permenent memory at first.
-    ; Then, Fixup the esp point to permenent memory
+    ; Save this function's return address into permanent memory at first.
+    ; Then, Fixup the esp point to permanent memory
     ;
     mov   eax, esp
@@ -58,17 +58,17 @@ SecSwitchStack   PROC
 
     ;
-    ; Fixup the ebp point to permenent memory
+    ; Fixup the ebp point to permanent memory
     ;
     mov   eax, ebp
-- 
2.21.0


-=-=-=-=-=-=-=-=-=-=-=-
Groups.io Links: You receive all messages sent to this group.

View/Reply Online (#51610): https://edk2.groups.io/g/devel/message/51610
Mute This Topic: https://groups.io/mt/65772991/1813853
Group Owner: devel+owner at edk2.groups.io
Unsubscribe: https://edk2.groups.io/g/devel/unsub  [edk2-devel-archive at redhat.com]
-=-=-=-=-=-=-=-=-=-=-=-





More information about the edk2-devel-archive mailing list